CHANGE LOG
==========

2.3.7
-----
- bump to official wagtail v1.0
- add health check

2.3.6
-----
- remove first_published_at from models (casuing migration issues)

2.3.3
-----
- added `extra styling hints` field to section page

2.3.2
-----
- allow articles to be featured on the homepage

2.3.1
-----
- `first published at` is not a required field

2.3.0
-----
- add homepage models
- ensure articles ordered by published date
- allow articles to be featured

2.2.1
-----
- Add images to sections
- Add support for sub sections

2.2.0
-----
- Add multi language support

2.1.1
-----
- ensure libffi-dev in sideloader build file

2.1.0
-----
- ensure libffi-dev in sideloader build file

2.1.0
-----
- Add basic models
- Add basic templates
- upgraded to v1.0b2

2.0.5
-----
- Add sideloader scripts

2.0.4
-----
- Fix cookie cutter path

2.0.3
-----
- pypi fix - include cookie cutter json

2.0.2
-----
- Use cookie cutter for a project template

2.0.1
-----
- Fix pypi package manifest

2.0.0
-----
- Initial release
